<#
    Sign DLL's in the specified intallation folder of Airwatch

    Usage: .\SignUemDlls.ps1 <full path to Workspace One UEM installation root folder. This value must be quoted. E.g. "C:\AirWatch\AirWatch 2302".
#>

$aw_install_root = $args[0].TrimEnd('/').TrimEnd('\')


$current_dir = split-path -parent $MyInvocation.MyCommand.Definition
cd $current_dir

$ca_pfx_path = $current_dir + "\ca_cert.pfx"
$ca_cert_path = $current_dir + "\ca_cert.cer"
$sign_pfx_path = $current_dir + "\signing_cert.pfx"
$sign_cert_path = $current_dir + "\signing_cert.cer"


$password=[guid]::NewGuid()
 .\AW.CodeSigningUtility.exe certgen -cpw $password

$secure_string_password = ConvertTo-SecureString $password -AsPlainText -Force

Import-PfxCertificate -FilePath $ca_pfx_path -Password $secure_string_password -CertStoreLocation cert:\LocalMachine\Root

#Stopping services
$svclist = @()
$svclist = $svclist = Get-Service AirWatch*, 'W3SVC'
$timeoutspan = New-TimeSpan -Minutes 1
Foreach ($service in $svclist) {
    if ($service.Status -ne "Stopped") {
        try {
            Stop-Service $service -Force -PassThru
        }
        catch {
            Write-Host "[WARN] Unable to stop $($service.name)"
        }
        $stop_service_attempts = 0
        do {
            try {
                $service.WaitForStatus("stopped", $timeoutspan)
            }
            catch {
                Write-Host "[WARN] $($service.name) Could not be Stopped, Attempting to Kill it`n"
                $stop_service_attempts++
            }
        } until ($stop_service_attempts -eq 5 -or $service.Status -eq "Stopped")

        if ($stop_service_attempts -ge 5) {
            # Get process id since the service is hung
            # Kill process
            $servicepid = ( Get-WmiObject Win32_Service | Where { $_.name -eq $service.name }).processID
            Stop-Process -Id $servicepid -Force -Confirm:$false
            Write-Host "Service hung. Killed $($service.name)"
        }
    }
}

$subfolders = @(
    "bin"
    )

For ($i=0; $i -lt $subfolders.Length; $i++) {
    $subfolder = $aw_install_root + "\" + $subfolders[$i]
    echo "Signing DLL's in $subfolder"
    .\AW.CodeSigningUtility.exe sign -sdir $subfolder -cloc $sign_pfx_path  -cpw $password -pcertloc $sign_pfx_path -pcertpw  $password -nthreads 4  
}


#del $ca_cert_path
#del $ca_pfx_path
#del $sign_cert_path
#del $sign_pfx_path

#Starting services
#get-service AirWatch* | start-service
#iisreset /start